import { wxMiniAppLogin } from '@/api/user'
import Vue from 'vue'
/**
 * 获取微信登录的code
 * @returns {Promise<unknown>}
 */
export const getWxLoginCode = () => {
  return new Promise((resolve, reject) => {
    uni.login({
      provider: 'weixin',
      success: (res) => {
        if (res?.code) {
          resolve(res.code)
        } else {
          reject(res.errMsg)
        }
      },
      fail: (e) => {
        reject(e)
      }
    })
  })
}

/**
 * 登录
 * @param params 登录入参
 * @param type 0 微信一键登录 1 密码登录 2 手机验证码登录
 * @returns {Promise<boolean>}
 */
export const login = async (params) => {
  try {
    let result = await wxMiniAppLogin(params)
    //模拟登录接口返回
    if (result.code === '00000') {
      const data = result?.data
      // save token
      saveToken(data)
    } else {
      this.$u.toast(result.message)
      return false
    }
    return true
  } catch (e) {
    console.error(e)
    return false
  }
}

/**
 * 保存token
 */
export const saveToken = (data) => {
  //模拟后台字段，后期修改
  Vue.$u.vuex('vuex_token', data.token)
  Vue.$u.vuex('vuex_user_info', data.user_info)
  Vue.$u.toast('登录成功！')
}
